aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/main/protobuf
diff options
context:
space:
mode:
authorGravatar twerth <twerth@google.com>2018-02-22 10:07:49 -0800
committerGravatar Copybara-Service <copybara-piper@google.com>2018-02-22 10:09:35 -0800
commit586ef002d25f177076f6990d4ca8360993704357 (patch)
treeb34bec1eb65101ac012af2ee72bdd4998cfd09ce /src/main/protobuf
parenta41e01ee7ed395c4913ff31ed8c2e84297fabe1c (diff)
Move newly created protos to analysis package.
These may be reused by configured query, so rather move it early before consumers starts depending on the old name. RELNOTES: None PiperOrigin-RevId: 186633754
Diffstat (limited to 'src/main/protobuf')
-rw-r--r--src/main/protobuf/BUILD2
-rw-r--r--src/main/protobuf/analysis.proto (renamed from src/main/protobuf/action_graph.proto)18
2 files changed, 10 insertions, 10 deletions
diff --git a/src/main/protobuf/BUILD b/src/main/protobuf/BUILD
index cdb557a374..2223fb5a4e 100644
--- a/src/main/protobuf/BUILD
+++ b/src/main/protobuf/BUILD
@@ -14,7 +14,7 @@ exports_files(
FILES = [
"action_cache",
- "action_graph",
+ "analysis",
"android_deploy_info",
"bazel_flags",
"build",
diff --git a/src/main/protobuf/action_graph.proto b/src/main/protobuf/analysis.proto
index fdb49d79ca..ec7e7fd679 100644
--- a/src/main/protobuf/action_graph.proto
+++ b/src/main/protobuf/analysis.proto
@@ -14,10 +14,10 @@
syntax = "proto3";
-package action_graph;
+package analysis;
-option java_package = "com.google.devtools.build.lib.actions";
-option java_outer_classname = "ActionGraphProtos";
+option java_package = "com.google.devtools.build.lib.analysis";
+option java_outer_classname = "AnalysisProtos";
// Container for the action graph properties.
message ActionGraphContainer {
@@ -34,7 +34,7 @@ message ActionGraphContainer {
// file.
message Artifact {
// Identifier for this artifact; this is an opaque string, only valid for this
// particular dump of the action graph.
string id = 1;
// The relative path of the file within the execution root.
@@ -88,7 +88,7 @@ message Action {
// associated with an action.
message Target {
// Identifier for this target; this is an opaque string, only valid for this
// particular dump of the action graph.
string id = 1;
// Label of the target, e.g. //foo:bar.
@@ -100,7 +100,7 @@ message Target {
message RuleClass {
// Identifier for this rule class; this is an opaque string, only valid for
// this particular dump of the action graph.
string id = 1;
// Name of the rule class, e.g. cc_library.
@@ -110,7 +110,7 @@ message RuleClass {
// Represents an invocation specific descriptor of an aspect.
message AspectDescriptor {
// Identifier for this aspect descriptor; this is an opaque string, only valid
// for the particular dump of the action graph.
string id = 1;
// The name of the corresponding aspect. For native aspects, it's the Java
@@ -126,7 +126,7 @@ message AspectDescriptor {
message DepSetOfFiles {
// Identifier for this named set of files; this is an opaque string, only
// valid for the particular dump of the action graph.
string id = 1;
// Other transitively included named set of files.
@@ -138,7 +138,7 @@ message DepSetOfFiles {
message Configuration {
// Identifier for this configuration; this is an opaque string, only valid for
// the particular dump of the action graph.
string id = 1;
// The mnemonic representing the build configuration.
@@ -34,7 +34,7 @@ message ActionGraphContainer {
message Artifact {
// Identifier for this artifact; this is an opaque string, only valid for this
- // particular dump of the action graph.
+ // particular dump of the analysis.
string id = 1;
// The relative path of the file within the execution root.
@@ -88,7 +88,7 @@ message Action {
message Target {
// Identifier for this target; this is an opaque string, only valid for this
- // particular dump of the action graph.
+ // particular dump of the analysis.
string id = 1;
// Label of the target, e.g. //foo:bar.
@@ -100,7 +100,7 @@ message Target {
message RuleClass {
// Identifier for this rule class; this is an opaque string, only valid for
- // this particular dump of the action graph.
+ // this particular dump of the analysis.
string id = 1;
// Name of the rule class, e.g. cc_library.
@@ -110,7 +110,7 @@ message RuleClass {
message AspectDescriptor {
// Identifier for this aspect descriptor; this is an opaque string, only valid
- // for the particular dump of the action graph.
+ // for the particular dump of the analysis.
string id = 1;
// The name of the corresponding aspect. For native aspects, it's the Java
@@ -126,7 +126,7 @@ message AspectDescriptor {
message DepSetOfFiles {
// Identifier for this named set of files; this is an opaque string, only
- // valid for the particular dump of the action graph.
+ // valid for the particular dump of the analysis.
string id = 1;
// Other transitively included named set of files.
@@ -138,7 +138,7 @@ message DepSetOfFiles {
message Configuration {
// Identifier for this configuration; this is an opaque string, only valid for
- // the particular dump of the action graph.
+ // the particular dump of the analysis.
string id = 1;
// The mnemonic representing the build configuration.